==> RsSmbv-4.80.0.9-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/User_/Apm_/Mode.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, ant_port_map: enums.EutraBfapMapMode, channel=repcap.Channel.Default) -> None:
		"""[SOURce<HW>]:BB:EUTRa:DL:USER<CH>:APM:MODE \n
		Defines the antenna port mapping method. \n
			:param ant_port_map: CB| RCB| FW CB Codebook RCB Random codebook FW Fixed weight
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.enum_scalar_to_str(ant_port_map, enums.EutraBfapMapMode)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{channel_cmd_val}:APM:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.EutraBfapMapMode:
		"""[SOURce<HW>]:BB:EUTRa:DL:USER<CH>:APM:MODE \n
		Defines the antenna port mapping method. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: ant_port_map: CB| RCB| FW CB Codebook RCB Random codebook FW Fixed weight"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{channel_cmd_val}:APM:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraBfapMapMode)

==> RsSmbv-4.80.0.12-py3-none-any.whl: RsSmbv/Implementations/Source_/Bb_/Eutra_/Dl_/User_/Apm_/Mode.py <==
from ........Internal.Core import Core
from ........Internal.CommandsGroup import CommandsGroup
from ........Internal import Conversions
from ........ import enums
from ........ import repcap


# noinspection PyPep8Naming,PyAttributeOutsideInit,SpellCheckingInspection
class Mode:
	"""Mode commands group definition. 1 total commands, 0 Sub-groups, 1 group commands"""

	def __init__(self, core: Core, parent):
		self._core = core
		self._base = CommandsGroup("mode", core, parent)

	def set(self, ant_port_map: enums.EutraBfapMapMode, channel=repcap.Channel.Default) -> None:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:APM:MODE \n
		Snippet: driver.source.bb.eutra.dl.user.apm.mode.set(ant_port_map = enums.EutraBfapMapMode.CB, channel = repcap.Channel.Default) \n
		Defines the antenna port mapping method. \n
			:param ant_port_map: CB| RCB| FW CB Codebook RCB Random codebook FW Fixed weight
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')"""
		param = Conversions.enum_scalar_to_str(ant_port_map, enums.EutraBfapMapMode)
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		self._core.io.write(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{channel_cmd_val}:APM:MODE {param}')

	# noinspection PyTypeChecker
	def get(self, channel=repcap.Channel.Default) -> enums.EutraBfapMapMode:
		"""SCPI: [SOURce<HW>]:BB:EUTRa:DL:USER<CH>:APM:MODE \n
		Snippet: value: enums.EutraBfapMapMode = driver.source.bb.eutra.dl.user.apm.mode.get(channel = repcap.Channel.Default) \n
		Defines the antenna port mapping method. \n
			:param channel: optional repeated capability selector. Default value: Nr1 (settable in the interface 'User')
			:return: ant_port_map: CB| RCB| FW CB Codebook RCB Random codebook FW Fixed weight"""
		channel_cmd_val = self._base.get_repcap_cmd_value(channel, repcap.Channel)
		response = self._core.io.query_str(f'SOURce<HwInstance>:BB:EUTRa:DL:USER{channel_cmd_val}:APM:MODE?')
		return Conversions.str_to_scalar_enum(response, enums.EutraBfapMapMode)
